pub struct AsmRegisterDr { /* private fields */ }Expand description
All debug registers.
This type is not part of the public API! It’s an implementation detail. The register identifiers, however, are part of the public API.
To use the registers, you must import everything from the module:
use iced_x86::code_asm::*;or import them from this module:
use iced_x86::code_asm::registers::*;or import only these registers:
use iced_x86::code_asm::registers::dr::*;Trait Implementations
Sourceimpl Clone for AsmRegisterDr
impl Clone for AsmRegisterDr
Sourcefn clone(&self) -> AsmRegisterDr
fn clone(&self) -> AsmRegisterDr
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CodeAsmMov<AsmRegister32, AsmRegisterDr> for CodeAssembler
impl CodeAsmMov<AsmRegister32, AsmRegisterDr> for CodeAssembler
fn mov( &mut self, op0: AsmRegister32, op1: AsmRegisterDr, ) -> Result<(), IcedError>
Sourceimpl CodeAsmMov<AsmRegister64, AsmRegisterDr> for CodeAssembler
impl CodeAsmMov<AsmRegister64, AsmRegisterDr> for CodeAssembler
fn mov( &mut self, op0: AsmRegister64, op1: AsmRegisterDr, ) -> Result<(), IcedError>
Sourceimpl CodeAsmMov<AsmRegisterDr, AsmRegister32> for CodeAssembler
impl CodeAsmMov<AsmRegisterDr, AsmRegister32> for CodeAssembler
fn mov( &mut self, op0: AsmRegisterDr, op1: AsmRegister32, ) -> Result<(), IcedError>
Sourceimpl CodeAsmMov<AsmRegisterDr, AsmRegister64> for CodeAssembler
impl CodeAsmMov<AsmRegisterDr, AsmRegister64> for CodeAssembler
fn mov( &mut self, op0: AsmRegisterDr, op1: AsmRegister64, ) -> Result<(), IcedError>
impl Copy for AsmRegisterDr
Sourceimpl Debug for AsmRegisterDr
impl Debug for AsmRegisterDr
impl Eq for AsmRegisterDr
Sourceimpl From<AsmRegisterDr> for Register
impl From<AsmRegisterDr> for Register
Sourcefn from(reg: AsmRegisterDr) -> Self
fn from(reg: AsmRegisterDr) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for AsmRegisterDr
impl PartialEq for AsmRegisterDr
Sourcefn eq(&self, other: &AsmRegisterDr) -> bool
fn eq(&self, other: &AsmRegisterDr) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for AsmRegisterDr