AsmRegisterSegment

Struct AsmRegisterSegment 

pub struct AsmRegisterSegment { /* private fields */ }
All segment registers.

This type is not part of the public API! It’s an implementation detail. The register identifiers, however, are part of the public API.

To use the registers, you must import everything from the module:

use iced_x86::code_asm::*;

or import them from this module:

use iced_x86::code_asm::registers::*;

or import only these registers:

use iced_x86::code_asm::registers::segment::*;