pub struct AsmRegisterTr { /* private fields */ }Expand description
All test registers.
This type is not part of the public API! It’s an implementation detail. The register identifiers, however, are part of the public API.
To use the registers, you must import everything from the module:
use iced_x86::code_asm::*;or import them from this module:
use iced_x86::code_asm::registers::*;or import only these registers:
use iced_x86::code_asm::registers::tr::*;Trait Implementations
Sourceimpl Clone for AsmRegisterTr
impl Clone for AsmRegisterTr
Sourcefn clone(&self) -> AsmRegisterTr
fn clone(&self) -> AsmRegisterTr
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CodeAsmMov<AsmRegister32, AsmRegisterTr> for CodeAssembler
impl CodeAsmMov<AsmRegister32, AsmRegisterTr> for CodeAssembler
fn mov( &mut self, op0: AsmRegister32, op1: AsmRegisterTr, ) -> Result<(), IcedError>
Sourceimpl CodeAsmMov<AsmRegisterTr, AsmRegister32> for CodeAssembler
impl CodeAsmMov<AsmRegisterTr, AsmRegister32> for CodeAssembler
fn mov( &mut self, op0: AsmRegisterTr, op1: AsmRegister32, ) -> Result<(), IcedError>
impl Copy for AsmRegisterTr
Sourceimpl Debug for AsmRegisterTr
impl Debug for AsmRegisterTr
impl Eq for AsmRegisterTr
Sourceimpl From<AsmRegisterTr> for Register
impl From<AsmRegisterTr> for Register
Sourcefn from(reg: AsmRegisterTr) -> Self
fn from(reg: AsmRegisterTr) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for AsmRegisterTr
impl PartialEq for AsmRegisterTr
Sourcefn eq(&self, other: &AsmRegisterTr) -> bool
fn eq(&self, other: &AsmRegisterTr) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for AsmRegisterTr