Enum iced_x86::DecoderError
source · #[non_exhaustive]
pub enum DecoderError {
None,
InvalidInstruction,
NoMoreBytes,
}Expand description
Decoder error
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
None
No error. The last decoded instruction is a valid instruction
InvalidInstruction
It’s an invalid instruction or an invalid encoding of an existing instruction (eg. some reserved bit is set/cleared)
NoMoreBytes
There’s not enough bytes left to decode the instruction
Implementations
sourceimpl DecoderError
impl DecoderError
sourcepub fn values(
) -> impl Iterator<Item = DecoderError> + DoubleEndedIterator + ExactSizeIterator + FusedIterator
pub fn values(
) -> impl Iterator<Item = DecoderError> + DoubleEndedIterator + ExactSizeIterator + FusedIterator
Iterates over all DecoderError enum values