pub struct BlockEncoderOptions;Expand description
BlockEncoder options
Implementations
Sourceimpl BlockEncoderOptions
impl BlockEncoderOptions
Sourcepub const DONT_FIX_BRANCHES: u32 = 0x0000_0001
pub const DONT_FIX_BRANCHES: u32 = 0x0000_0001
By default, branches get updated if the target is too far away, eg. Jcc SHORT -> Jcc NEAR or if 64-bit mode, Jcc + JMP [RIP+mem]. If this option is enabled, no branches are fixed.
Sourcepub const RETURN_RELOC_INFOS: u32 = 0x0000_0002
pub const RETURN_RELOC_INFOS: u32 = 0x0000_0002
The BlockEncoder should return RelocInfos
Sourcepub const RETURN_NEW_INSTRUCTION_OFFSETS: u32 = 0x0000_0004
pub const RETURN_NEW_INSTRUCTION_OFFSETS: u32 = 0x0000_0004
The BlockEncoder should return new instruction offsets
Sourcepub const RETURN_CONSTANT_OFFSETS: u32 = 0x0000_0008
pub const RETURN_CONSTANT_OFFSETS: u32 = 0x0000_0008
The BlockEncoder should return ConstantOffsets