FastFormatterOptions

Struct FastFormatterOptions 

pub struct FastFormatterOptions { /* private fields */ }
Fast formatter options

Implementations

Source

impl FastFormatterOptions

pub const fn space_after_operand_separator(&self) -> bool

Add a space after the operand separator

DefaultValueExample
_truemov rax, rcx
👍falsemov rax,rcx
pub fn set_space_after_operand_separator(&mut self, value: bool)

Add a space after the operand separator

DefaultValueExample
_truemov rax, rcx
👍falsemov rax,rcx
Arguments
  • value: New value
pub const fn rip_relative_addresses(&self) -> bool

Show RIP+displ or the virtual address

DefaultValueExample
_truemov eax,[rip+12345678h]
👍falsemov eax,[1029384756AFBECDh]
pub fn set_rip_relative_addresses(&mut self, value: bool)

Show RIP+displ or the virtual address

DefaultValueExample
_truemov eax,[rip+12345678h]
👍falsemov eax,[1029384756AFBECDh]
Arguments
  • value: New value
pub const fn use_pseudo_ops(&self) -> bool

Use pseudo instructions

DefaultValueExample
👍truevcmpnltsd xmm2,xmm6,xmm3
_falsevcmpsd xmm2,xmm6,xmm3,5h
pub fn set_use_pseudo_ops(&mut self, value: bool)

Use pseudo instructions

DefaultValueExample
👍truevcmpnltsd xmm2,xmm6,xmm3
_falsevcmpsd xmm2,xmm6,xmm3,5h
Arguments
  • value: New value
pub const fn show_symbol_address(&self) -> bool

Show the original value after the symbol name

DefaultValueExample
_truemov eax,[myfield (12345678)]
👍falsemov eax,[myfield]
pub fn set_show_symbol_address(&mut self, value: bool)

Show the original value after the symbol name

DefaultValueExample
_truemov eax,[myfield (12345678)]
👍falsemov eax,[myfield]
Arguments
  • value: New value
pub const fn always_show_segment_register(&self) -> bool

Always show the effective segment register. If the option is false, only show the segment register if there’s a segment override prefix.

DefaultValueExample
_truemov eax,ds:[ecx]
👍falsemov eax,[ecx]
pub fn set_always_show_segment_register(&mut self, value: bool)

Always show the effective segment register. If the option is false, only show the segment register if there’s a segment override prefix.

DefaultValueExample
_truemov eax,ds:[ecx]
👍falsemov eax,[ecx]
Arguments
  • value: New value
pub const fn always_show_memory_size(&self) -> bool

Always show the size of memory operands

DefaultValueExampleExample
_truemov eax,dword ptr [ebx]add byte ptr [eax],0x12
👍falsemov eax,[ebx]add byte ptr [eax],0x12
pub fn set_always_show_memory_size(&mut self, value: bool)

Always show the size of memory operands

DefaultValueExampleExample
_truemov eax,dword ptr [ebx]add byte ptr [eax],0x12
👍falsemov eax,[ebx]add byte ptr [eax],0x12
Arguments
  • value: New value
pub const fn uppercase_hex(&self) -> bool

Use uppercase hex digits

DefaultValueExample
👍true0xFF
_false0xff
pub fn set_uppercase_hex(&mut self, value: bool)

Use uppercase hex digits

DefaultValueExample
👍true0xFF
_false0xff
Arguments
  • value: New value
pub const fn use_hex_prefix(&self) -> bool

Use a hex prefix (0x) or a hex suffix (h)

DefaultValueExample
_true0x5A
👍false5Ah
pub fn set_use_hex_prefix(&mut self, value: bool)

Use a hex prefix (0x) or a hex suffix (h)

DefaultValueExample
_true0x5A
👍false5Ah
Arguments
  • value: New value