pub struct FastFormatterOptions { /* private fields */ }Expand description
Fast formatter options
Implementations
Sourceimpl FastFormatterOptions
impl FastFormatterOptions
Sourcepub const fn space_after_operand_separator(&self) -> bool
pub const fn space_after_operand_separator(&self) -> bool
Add a space after the operand separator
| Default | Value | Example |
|---|---|---|
| _ | true | mov rax, rcx |
| 👍 | false | mov rax,rcx |
Sourcepub fn set_space_after_operand_separator(&mut self, value: bool)
pub fn set_space_after_operand_separator(&mut self, value: bool)
Add a space after the operand separator
| Default | Value | Example |
|---|---|---|
| _ | true | mov rax, rcx |
| 👍 | false | mov rax,rcx |
Arguments
value: New value
Sourcepub const fn rip_relative_addresses(&self) -> bool
pub const fn rip_relative_addresses(&self) -> bool
Show RIP+displ or the virtual address
| Default | Value | Example |
|---|---|---|
| _ | true | mov eax,[rip+12345678h] |
| 👍 | false | mov eax,[1029384756AFBECDh] |
Sourcepub fn set_rip_relative_addresses(&mut self, value: bool)
pub fn set_rip_relative_addresses(&mut self, value: bool)
Show RIP+displ or the virtual address
| Default | Value | Example |
|---|---|---|
| _ | true | mov eax,[rip+12345678h] |
| 👍 | false | mov eax,[1029384756AFBECDh] |
Arguments
value: New value
Sourcepub const fn use_pseudo_ops(&self) -> bool
pub const fn use_pseudo_ops(&self) -> bool
Use pseudo instructions
| Default | Value | Example |
|---|---|---|
| 👍 | true | vcmpnltsd xmm2,xmm6,xmm3 |
| _ | false | vcmpsd xmm2,xmm6,xmm3,5h |
Sourcepub fn set_use_pseudo_ops(&mut self, value: bool)
pub fn set_use_pseudo_ops(&mut self, value: bool)
Use pseudo instructions
| Default | Value | Example |
|---|---|---|
| 👍 | true | vcmpnltsd xmm2,xmm6,xmm3 |
| _ | false | vcmpsd xmm2,xmm6,xmm3,5h |
Arguments
value: New value
Sourcepub const fn show_symbol_address(&self) -> bool
pub const fn show_symbol_address(&self) -> bool
Show the original value after the symbol name
| Default | Value | Example |
|---|---|---|
| _ | true | mov eax,[myfield (12345678)] |
| 👍 | false | mov eax,[myfield] |
Sourcepub fn set_show_symbol_address(&mut self, value: bool)
pub fn set_show_symbol_address(&mut self, value: bool)
Show the original value after the symbol name
| Default | Value | Example |
|---|---|---|
| _ | true | mov eax,[myfield (12345678)] |
| 👍 | false | mov eax,[myfield] |
Arguments
value: New value
Sourcepub const fn always_show_segment_register(&self) -> bool
pub const fn always_show_segment_register(&self) -> bool
Always show the effective segment register. If the option is false, only show the segment register if
there’s a segment override prefix.
| Default | Value | Example |
|---|---|---|
| _ | true | mov eax,ds:[ecx] |
| 👍 | false | mov eax,[ecx] |
Sourcepub fn set_always_show_segment_register(&mut self, value: bool)
pub fn set_always_show_segment_register(&mut self, value: bool)
Always show the effective segment register. If the option is false, only show the segment register if
there’s a segment override prefix.
| Default | Value | Example |
|---|---|---|
| _ | true | mov eax,ds:[ecx] |
| 👍 | false | mov eax,[ecx] |
Arguments
value: New value
Sourcepub const fn always_show_memory_size(&self) -> bool
pub const fn always_show_memory_size(&self) -> bool
Always show the size of memory operands
| Default | Value | Example | Example |
|---|---|---|---|
| _ | true | mov eax,dword ptr [ebx] | add byte ptr [eax],0x12 |
| 👍 | false | mov eax,[ebx] | add byte ptr [eax],0x12 |
Sourcepub fn set_always_show_memory_size(&mut self, value: bool)
pub fn set_always_show_memory_size(&mut self, value: bool)
Always show the size of memory operands
| Default | Value | Example | Example |
|---|---|---|---|
| _ | true | mov eax,dword ptr [ebx] | add byte ptr [eax],0x12 |
| 👍 | false | mov eax,[ebx] | add byte ptr [eax],0x12 |
Arguments
value: New value
Sourcepub const fn uppercase_hex(&self) -> bool
pub const fn uppercase_hex(&self) -> bool
Use uppercase hex digits
| Default | Value | Example |
|---|---|---|
| 👍 | true | 0xFF |
| _ | false | 0xff |
Sourcepub fn set_uppercase_hex(&mut self, value: bool)
pub fn set_uppercase_hex(&mut self, value: bool)
Sourcepub const fn use_hex_prefix(&self) -> bool
pub const fn use_hex_prefix(&self) -> bool
Use a hex prefix (0x) or a hex suffix (h)
| Default | Value | Example |
|---|---|---|
| _ | true | 0x5A |
| 👍 | false | 5Ah |
Sourcepub fn set_use_hex_prefix(&mut self, value: bool)
pub fn set_use_hex_prefix(&mut self, value: bool)
Use a hex prefix (0x) or a hex suffix (h)
| Default | Value | Example |
|---|---|---|
| _ | true | 0x5A |
| 👍 | false | 5Ah |
Arguments
value: New value